import java.util.ArrayList;

/**
 * Account class holds the identifier, name and current balance
 */
public abstract class Account
{
    // instance variables
    private int accountNumber;
    private float startingBalance;
    private ArrayList<Transaction> transactions;
    private float balance;
  
    /**
     * Constructor for objects of class Account
     * 
     * @param  accountNumber    the account number
     * @param  startingBalance  the starting balance
     * @param  creditLimit      the credit limit (internally, this is negated to give
     *                          the maximum overdraft allowed
     */
    public Account(int accountNumber, float startingBalance)
    {
        this.accountNumber = accountNumber;
        this.startingBalance = startingBalance;
        balance = startingBalance;
        transactions = new ArrayList<Transaction>();
    }

    /**
     * Accessor method for account number
     */
    public int getAccountNumber()
    {
        return accountNumber;
    }

    /**
     * Accessor method for balance
     */
    public float getBalance()
    {
        return balance;
    }

    /**
     * Mutator method for balance
     */
    protected void setBalance(float b)
    {
        balance = b;
    }

    /**
     * Mutator method for balance
     */
    protected void addTransaction(Transaction t)
    {
        if (t != null)
            transactions.add(t);
    }

    /**
     * Perform a transaction on this account.
     * This is a placeholder allowing subclasses to override this method.
     * 
     * @param  t   the transaction object
    */
    public boolean updateBalance(Transaction t)
    {
       System.out.println("This should never be executed");
       return false;
    }

    /**
     * Calculate the interest for this account over a period (e.g. one month)
     *
     * The declaration here is just a placeholder and should never be executed.
     * It is here to allow subclasses to define their own interest calculation
     */
    public void periodInterest(Journal J)
    {
        System.out.println("This should be overridden");
    }

    /**
     * Print the opening balance.
     * Iterate through the transactions for the account
     * and print the closing balance.
     */
    public void report()
    {
        System.out.println("Account " + accountNumber + " opening balance $" + startingBalance);
        for (Transaction t: transactions)
        {
            System.out.println("        " + t);
        }
        System.out.println("        Closing balance $" + balance);
    }
}
