import java.util.ArrayList;

/**
 * A journal contains a list of transactions.
 */
public class Journal
{
    private ArrayList<Transaction> transactions;
    private boolean processed = false;

    /**
     * Constructor for objects of class Journal
     */
    public Journal()
    {
        transactions = new ArrayList<Transaction>();
    }

    /**
     * Add a transaction to the journal. It is not processed here.
     * 
     * @param  t   the new transaction
     */
    public void addTransaction(Transaction t)
    {
        transactions.add(t);
    }

    /**
     * Return the list of transactions in the journal
     *
     * @return     the transaction ArrayList
     */
    public ArrayList<Transaction> getTransactions()
    {
        return transactions;
    }

    /**
     * Process all the transactions in this journal.
     * A journal, and hence all the transactions in the journal, should only be processed once.
     *
     * @param  L   the ledger these journal transactions should be applied to
     */
    public void process(Ledger L)
    {
        if (processed)
        {
            System.out.print("This journal has already been processed");
            return;
        }
        
        for (Transaction t: transactions)
        {
            t.process(L);
        }
        
        processed = true;
    }

}
