import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;

/**
 * A ledger is a collection of accounts stored as a HashMap. Each account is accessed by
 * its unique integer identifier.
 */
public class Ledger
{
    private HashMap<Integer, Account> accounts;

    /**
     * Constructor for objects of class Ledger
     */
    public Ledger()
    {
        accounts = new HashMap<Integer, Account>();
    }

    /**
     * Add a new account to the accounts HashMap
     *
     * @param  id  the unique account number
     * @param  acc the account object to be stored in the HashMap
     */
    public void addAccount(int id, Account acc)
    {
        accounts.put(id, acc);
    }

    /**
     * Given an account number, return the account object
     *
     * @param  accNo   the account number
     * @return         the account object that matches the number in the hash table
     */
    public Account getAccount(int accNo)
    {
        return accounts.get(accNo);
    }

    /**
     * This method should be run periodically to update the interest for each account
     * 
     * @param J  The journal in which and interest payments are charges are recorded
     */
    public void calculateInterest(Journal J)
    {
        Iterator i = accounts.values().iterator();
        
        while (i.hasNext())
        {
            Account a = (Account)(i.next());
            a.periodInterest(J);
        }
    }

    /**
     * Iterate through all the accounts in the ledger and call report for each of them
     * This code to be provided to the student.
     */
    public void report()
    {
        Iterator i = accounts.values().iterator();
        
        System.out.println("---------------");
        while (i.hasNext())
        {
            Account a = (Account)(i.next());
            a.report();
        }
    }
}
